#!/usr/bin/env python

import os, sys
from distutils.core import setup
from distutils.extension import Extension
from distutils.sysconfig import get_python_lib

"""The purpose of this module was to let Python access X11 idle times.
It does little more than that:

>>> import xss 
>>> info = xss.get_info()
>>> print info.idle
10
>>> print info.state
0
>>> print info.state == xss.ScreenSaverDisabled
0
>>> print info.state == xss.ScreenSaverOff
1

Other attributes are:

typedef struct {
    Window  window;     /* screen saver window - may not exist */
    int     state;      /* ScreenSaverOff, ScreenSaverOn, ScreenSaverDisabled*/
    int     kind;       /* ScreenSaverBlanked, ...Internal, ...External */
    unsigned long    til_or_since;   /* time til or since screen saver */
    unsigned long    idle;      /* total time since last user input */
    unsigned long   eventMask; /* currently selected events for this client */
} XScreenSaverInfo;

The window attribute will be useless.  For state and kind, you can test the
values against their named values 
(i.e. "print info.state == xss.ScreenSaverOff")

As of version 2.1, we now include IdleTracker and XSSTracker, which are
higher level interfaces.  Both keep track of the current idle time and tell
you whether the user became idle or unidle since the last poll, when the
next poll should take place, and the current idle time in milliseconds.
IdleTracker is based on some threshold for idle time, while XSSTracker 
announces that the user is idle when the screensaver activates.  An example
poller can be found at the end of this file (xss/__init__.py)."""

def have_swig(print_config=1):
    """Returns whether SWIG can be found using the 'which' command"""
    if print_config: print "Checking for SWIG...",

    # TODO: the following might not be too portable
    swig = os.popen('which swig', 'r')
    if print_config: 
        # this prints the location of SWIG, removing the carriage return
        print swig.read()[:-1]

    # if they have SWIG (return value of close() is exit code)
    return not swig.close()

print_config = 1
if sys.argv[-1] == 'setup.py':
    print "To install, run 'python setup.py install'"
    print
    print_config = 0

if have_swig(print_config=print_config):
    extension_file = 'xss/xss.i'
else:
    if print_config: print "nope -- you'll use the pre-SWIGed version"
    extension_file = 'xss/xss.c' # C file (post-SWIGged)

setup(name='PyXSS', version=2.1, 
      description="Python Interface to XScreenSaver",
      long_description=__doc__,
      author="David McClosky", author_email="dmcc@bigasterisk.com",
      maintainer="David McClosky", maintainer_email="dmcc@bigasterisk.com",
      keywords=['X11', 'screensaver', 'XFree86', 'idle'], 
      platforms=['POSIX/X11'],
      url="http://bebop.bigasterisk.com/python", license="GPLv2",
      packages=['xss'],
      ext_modules=[
        Extension('xss._xss', [extension_file], 
                  libraries=['Xss', 'Xext'],
                  library_dirs=['/usr/X11R6/lib'])
      ])
